# FieldOptions9

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**field_id_in_linked_table** | **str** | The id of the field in the linked table | [optional] 
**is_valid** | **bool** | Whether the lookup is valid | [optional] 
**record_link_field_id** | **str** | The id of the linked field | [optional] 
**result** | **object** | The computed result of the lookup | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

